"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const SHA256 = require("crypto-js/sha256");
function normalizeDecimal(decimalNumber) {
    const num = decimalNumber.split('.');
    let result = decimalNumber;
    if (num.length === 1) {
        result += '000000000000000000';
    }
    else {
        const decimalPart = num[1];
        for (let i = 18; i > decimalPart.length; i -= 1) {
            result += '0';
        }
    }
    return result;
}
function generateVoteHash(salt, price, denom, voter) {
    const proof = `${salt}:${normalizeDecimal(price)}:${denom}:${voter}`;
    const hash = SHA256(proof).toString(); // hex string
    return hash.slice(0, 40); // 20 prefix bytes
}
exports.generateVoteHash = generateVoteHash;
function buildStdTx(msg, fee, memo) {
    return {
        type: 'auth/StdTx',
        value: {
            fee,
            memo,
            msg,
            signatures: []
        }
    };
}
exports.buildStdTx = buildStdTx;
function buildPricePrevoteMsg(hash, denom, feeder, validator) {
    return {
        type: 'oracle/MsgPricePrevote',
        value: {
            hash,
            denom,
            feeder,
            validator
        }
    };
}
exports.buildPricePrevoteMsg = buildPricePrevoteMsg;
function buildPriceVote(price, salt, denom, feeder, validator) {
    return {
        type: 'oracle/MsgPriceVote',
        value: {
            price,
            salt,
            denom,
            feeder,
            validator
        }
    };
}
exports.buildPriceVote = buildPriceVote;
function buildSend(amount, fromAddress, toAddress) {
    return {
        type: 'pay/MsgSend',
        value: {
            amount: amount,
            from_address: fromAddress,
            to_address: toAddress
        }
    };
}
exports.buildSend = buildSend;
function buildMultiSend(inputs, outputs) {
    return {
        type: 'pay/MsgMultiSend',
        value: {
            inputs,
            outputs
        }
    };
}
exports.buildMultiSend = buildMultiSend;
//# sourceMappingURL=msgUtils.js.map